// count数据字典
const countDictionary = [
	{
		id: 'countTraitTrait',
		countSectionName: 'offTraitCount',
		countModuleName: 'trait',
		sectionName: '品种测试',
		moduleName: '性状采集'
	},
	{
		id: 'countTraitField',
		countSectionName: 'offTraitCount',
		countModuleName: 'field',
		sectionName: '品种测试',
		moduleName: '田间管理'
	},
	{
		id: 'countTraitEval',
		countSectionName: 'offTraitCount',
		countModuleName: 'eval',
		sectionName: '品种测试',
		moduleName: '综合评价'
	},
	{
		id: 'countTrait',
		countSectionName: 'offBreedCount',
		countModuleName: 'trait',
		sectionName: '材料繁育',
		moduleName: '性状采集'
	},
	{
		id: 'countHybrid',
		countSectionName: 'offBreedCount',
		countModuleName: 'hybrid',
		sectionName: '材料繁育',
		moduleName: '杂交实施'
	},
	{
		id: 'countSeed',
		countSectionName: 'offBreedCount',
		countModuleName: 'seed',
		sectionName: '材料繁育',
		moduleName: '收种执行'
	},
	{
		id: 'countField',
		countSectionName: 'offBreedCount',
		countModuleName: 'field',
		sectionName: '材料繁育',
		moduleName: '田间管理'
	}
]

// 获取模块权限
function getModulePermission(moduleName) {
	return new Promise((resolve, reject) => {
		window.model.post('hzapp/user/validmodule.do', {resText: moduleName}, function(response) {
			// 请求成功则返回相应中的code
			resolve(response.code)
		}, function(xhr, type, errorThrown) {
			// 请求失败则返回错误
			const error = {
				xhr,
				type,
				errorThrown
			}
			reject(error)
		})
	})
}

// 异步执行
async function delayedPermissionReceiver(module) {
	// 等待promise返回
	const permission = await getModulePermission(module.res_text)
	// 给对应模块添加权限
	module.permission = permission === 1
}

// 处理模块权限
async function processPermission(moduleList) {
	// 大模块串行，小模块并行请求获取权限
	for (let i = 0; i < moduleList.length; i++) {
		// 将模块数组转换成promise数组
		const promises = moduleList[i].modules.map(delayedPermissionReceiver)
		// 并发执行模块数组中的所有请求
		await Promise.all(promises)
	}
	renderModule2(moduleList)
}

// 处理模块
function processModule(moduleList) {
	processPermission(moduleList)
}



// 生成module的innerHTML
function ModuleHTML(module) {
	this.id = module.res_id
	this.name = module.res_text
	this.sectionName = module.sectionName
	this.href = ''
	this.icon = ''
	this.pathFrom = ''
	this.badgeID = ''
	this.count = 0
	this.HTMLText = ''
	this.classNames = ["item-sub", "dp-flex-col-xy-center"]
	this.style = "position: relative;"
	this.readResouceURL = function(moduleResouces) {
		const moduleKey = this.sectionName + '-' + this.name
		const moduleResouce = moduleResouces[moduleKey]
		this.href = moduleResouce.href
		this.icon = moduleResouce.icon
		this.pathFrom = moduleResouce.pathFrom
	}
	this.readCount = function(countData, countDictionary) {
		for (let item of countDictionary) {
			if (item.id === this.badgeID) {
				this.count = countData[item.countSectionName][item.countModuleName]
			}
		}
	}
	this.generateHTMLText = function() {
		let startTagStr = ''
		let contentStr = ''
		let endTagStr = ''
		
		startTagStr += '<div'
		startTagStr += ' class=' + '"' + this.classNames.join(' ') + '"'
		startTagStr += ' style=' + '"' + this.style + '"'
		startTagStr += ' id=' + '"' + this.id + '"' + '"'
		startTagStr += ' target-href=' + '"' + this.href + '"'
		startTagStr += ' data-pathfrom="' + '"' + this.pathFrom + '"'
		startTagStr += '>'
		
		if (this.count > 0) {
			contentStr += '<span class="mui-badge mui-badge-upload mui-badge-danger" id="countTrait" style="right: 10px;">' + this.count+ '</span>'
		}
		contentStr += '<p class="item-sub-name">' + this.name + '</p>'
		contentStr += '<img src="' + this.icon + '" class="item-sub-icon">'
		
		endTagStr += '</div>'
		
		this.HTMLText = startTagStr + contentStr + endTagStr
		return this.HTMLText
	}
}

// 在线模式模块渲染方法
function renderOnlineModule(moduleList) {
	const countData = {
		offBreedCount,
		offTraitCount
	}
	let modulesStr = '<div class="item home-module-item">'
	mui.each(moduleList, function(index, module) {
		modulesStr += '<div class="item-title"><div class="item-name">' + module.res_text + '</div>'
		if (module.res_text === '品种测试') {
			modulesStr += '<div class="item-action yellow submit-variety">上传提交'
			modulesStr += '</div>'
		} else if (module.res_text === '材料繁育') {
			modulesStr += '<div class="item-action green submit-breed">上传提交'
			modulesStr += '</div>'
		}
		
		modulesStr += '</div>'
		if (module.modules && Array.isArray(module.modules)) {
			modulesStr += '<div class="item-content"><div class="item-content-wrap">'
			mui.each(module.modules, function(moduleIndex, moduleItem) {
				const params = {
					...moduleItem,
					sectionName: module.res_text
				}
				const moduleHTML = new ModuleHTML(params)
				moduleHTML.readCount(countData, countDictionary)
				moduleHTML.readResouceURL(moduleUrl)
				// modulesStr += moduleHTML.generateHTMLText()
				const moduleHTMLText = moduleHTML.generateHTMLText()
				
				// console.log(moduleHTMLText)
				modulesStr += moduleHTMLText
			})
			modulesStr += '</div>'
		}
		
	})
	modulesStr += '</div>'
	document.getElementById('modules').innerHTML = modulesStr
}

// 生成离线模式的模块列表
function generateOfflineModuleList(moduleList) {
	const offlineSectionList = [
		'材料繁育',
		'品种测试'
	]
	return moduleList.filter(section => {
		return offlineSectionList.includes(section.res_text)
	}).map(section => {
		section.modules = section.modules.filter(module => {
			return module.res_mode === "OFFLINE"
		})
		return section
	})
	
	
}

// 新模块渲染方法
function renderModule2(moduleList) {
	// console.log('module list:' + JSON.stringify(moduleList))
	// var status = localStorage.getItem('offline');
	var status = 'off'
	
	if (status === 'on') {
		renderOnlineModule(moduleList)
	} else {
		const offlineModuleList = generateOfflineModuleList(moduleList)
		renderOnlineModule(offlineModuleList)
	}
	
	// 添加底部导航栏点击事件监听，及跳转
	mui('.home-module-item').on('tap', '.item-sub', function(e) {
		// 判断用户是否有权限
		const tappedModuleID = this.getAttribute('id')
		let hasPermission = false
		modulesInfo.forEach(section => {
			section.modules.forEach(module => {
				if (module.res_id.toString() === tappedModuleID) {
					hasPermission = module.permission
				}
			})
		})
		if (!hasPermission) {
			console.log('access denied')
			mui.toast('没有权限，请联系管理员！',{ duration:700, type:'div' }) 
			return
		}
		let href = this.getAttribute('target-href')
		let page = plus.webview.getWebviewById(href)
		if (page) {
			mui.fire(page, 'homeRefresh', {})
		}
		mui.openWindow({
			url: href,
			id: href,
			extras: {
				pathFrom: this.getAttribute('data-pathfrom'),
			}
	
		})
	})
	localStorage.setItem("zhiHuiWuLian", moduleList[3].modules[1].res_url)
	// 提交材料繁育
	mui('.home-module-item').on('tap', '.submit-breed', function() {
		submitBreeding()
	})
	mui('.home-module-item').on('tap', '.submit-variety', function() {
		submitVariety()
	})
}